package org.greenstone.gsdl3.gs3build.metadata;

import java.io.PrintWriter;

import java.util.HashMap;
import java.util.Map;
import java.util.List;
import java.util.ArrayList;
import java.util.Iterator;

import java.sql.SQLException;
import java.sql.ResultSet;

import org.greenstone.gsdl3.gs3build.doctypes.DocumentInterface;

import org.greenstone.gsdl3.gs3build.util.GS3SQLConnection;
import org.greenstone.gsdl3.gs3build.database.*;

public class METSStructureSet
{ Map children;

  public METSStructureSet()
  { this.children = new HashMap();
  }

  public void addStructure(METSStructure structure)
  { this.children.put(structure.getID(), structure);
  }

  public METSStructure getStructure(String name)
  { return (METSStructure) this.children.get(name);
  }

  /**
   *  Find the divisions that contain a list of given files
   *
   *  @param <code>List</code> the list of files to find...
   *  @return <code>List</code> the matching divisions.
   */
  public List findDivisionsForFiles(List listOfFileIdentifiers)
  { List reply = new ArrayList();

    // iterate across all the children...
    Iterator structures = this.children.values().iterator();
    
    while (structures.hasNext())
    { METSStructure structure = (METSStructure) structures.next();

      structure.findDivisionsForFiles(listOfFileIdentifiers, reply);      
    }    
    return reply;
  }

  /**
   *  Add a division to an indicated structure.
   *
   *  @param <code>String</code> the structure identifier
   *  @param <code>METSDivision</code> the division to be added.
   */
  public void addDivision(String structureName, METSDivision division)
  { METSStructure structure = (METSStructure) this.children.get(structureName);

    if (structure != null)
    { structure.addDivision(division);
    }
  }

  /**
   *  Add a division to an indicated division within structure.
   *
   *  @param <code>String</code> the structure identifier
   *  @param <code>String</code> the division identifer, within which the division
   *         is to be placed.
   *  @param <code>METSDivision</code> the division to be added.
   */
  public void addSubDivision(String structureName, String divisionID, METSDivision division)
  { METSStructure structure = (METSStructure) this.children.get(structureName);

    if (structure != null)
    { structure.addSubDivision(divisionID, division);
    }
  }

  public METSDivision getDivision(String structureName, String divisionID)
  { METSStructure structure = (METSStructure) this.children.get(structureName);

    if (structure != null)
    { return structure.getDivision(divisionID);
    }
    return null;
  }

  public void write(PrintWriter writer)
  { Iterator structures = this.children.values().iterator();

    while (structures.hasNext())
    { METSStructure group = (METSStructure) structures.next();

      group.write(writer);
    }
  }

  public boolean writeSQL(DocumentInterface document, GS3SQLConnection connection)
  { Iterator structures = this.children.values().iterator();
    
    while (structures.hasNext())
    { METSStructure group = (METSStructure) structures.next();

      if (!group.writeSQL(document, connection))
      { return false;
      }
    }
    return true;
  }

  public static METSStructureSet readSQL(DocumentInterface document, GS3SQLConnection connection)
  { 
    METSStructureSet set = new METSStructureSet();

    GS3SQLSelect select = new GS3SQLSelect("structure");
    select.addField("*");
    GS3SQLWhereItem whereItem = new GS3SQLWhereItem("DocID", "=", document.getID().toString());
    select.setWhere(new GS3SQLWhere(whereItem));
    connection.execute(select.toString());

    // start going through the matching metadata blocks
    try {
      ResultSet resultSet = connection.getResultSet();
      resultSet.first();
      do {
	METSStructure structure = METSStructure.readSQL(document, connection, resultSet);
	if (structure != null) {
	  set.addStructure(structure);
	}
      } while (resultSet.next());
    }
    catch (SQLException sqlEx) {
      System.out.println(sqlEx);
      System.exit(1);
    }

    return set;
  }

}
